from typing import Dict, List, Union

Vector = List[float]
StringDictionary = Dict[str, str]
NumberDictionary = Dict[str, float]
OrderedDictionary = Dict[int, str]
NumType = Union[Vector, NumberDictionary, int, float, list]